==> 0.1.0a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/model/KoreanData.kt <==
package model

import recipeappkmp.shared.generated.resources.Res
import recipeappkmp.shared.generated.resources._10_strawberries
import kotlin.time.Duration

val koreanList = listOf(
    Recipe(
        title = "Oi Muchim | Spicy Cucumber Salad",
        description = "Cucumbers tossed in vinegar and chili spices.",
        ingredients = listOf(
            "1 Cucumber",
            "1 Tsp Salt",
            "1 Tbsp Gochugaru",
            "1 Tbsp Scallion, chopped",
            "1 Tsp Garlic, minced",
            "1 Tsp Vinegar",
            "1/2 Tsp Sugar",
            "1 tsp Sesame Seeds",
            "1 Tsp Sesame Oil",
        ),
        instructions = listOf(
            "Thinly slice the Cucumber. Sprinkle with Salt [1 Tsp] and rest for 20 minutes.",
            "Drain liquid from Cucumbers, then toss in remaining ingredients.",
        ),
        tags = mapOf(
            "Korean" to TagType.CUISINE,
            "Appetizer" to TagType.COURSE,
            "Spicy" to TagType.FLAVOUR,
        ),
        image = Res.drawable._10_strawberries,
        cookTime = Duration.ZERO,
        prepTime = Duration.parse("30m")
    ),

    Recipe(
        title = "Korean Stir Fry Sauce",
        description = "Sweet and Spicy Korean Stir Fry Sauce.",
        ingredients = listOf(
            "1.5 Tbsp Gochujang",
            "2 Tsp Gochugaru",
            "1 Tbsp Garlic, minced",
            "1 Tsp Ginger, grated",
            "2 Tsp Honey",
            "1 Tbsp Soy",
            "1 Tbsp Mirin",
            "1.5 Tsp Brown Sugar",
            "Juice of 1 Lime",
        ),
        instructions = listOf(
            "Combine ingredients",
        ),
        tags = mapOf(
            "Korean" to TagType.CUISINE,
            "Sauce" to TagType.COURSE,
            "Spicy" to TagType.FLAVOUR,
            "Sweet" to TagType.FLAVOUR,
        ),
        image = Res.drawable._10_strawberries,
        cookTime = Duration.ZERO,
        prepTime = Duration.parse("10m")
    ),

    Recipe(
        title = "Bulgolgi",
        description = "",
        ingredients = listOf(
            "2 Scallion",
            "1 Large Onion",
            "1 lb Protein of choice",
            "3 Tbsp Gochujang",
            "1 tsp Gochugaru",
            "2 Tbsp Soy",
            "2 Tbsp Mirin",
            "1.5 Tbsp Sugar",
            "1 Tbsp Sesame Oil",
            "1 Tbsp Garlic, minced",
            "1 Tbsp Ginger, grated",
            "1/4 Tsp Black Pepper"
        ),
        instructions = listOf(
            "Mix all ingredients except Scallions together. Marinate 1h, up to overnight",
            "Stir Fry until onions are done, protein is finished cooking, etc...",
            "Garnish with Scallions and serve"
        ),
        tags = mapOf(
            "Korean" to TagType.CUISINE,
            "Entree" to TagType.COURSE,
            "Spicy" to TagType.FLAVOUR,
            "Savory" to TagType.FLAVOUR,
            "Stir Fry" to TagType.TECHNIQUE,
        ),
        image = Res.drawable._10_strawberries,
        cookTime = Duration.parse("30m"),
        prepTime = Duration.parse("8h")
    ),
)

==> 0.1.2a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/model/KoreanData.kt <==
package model

import recipeappkmp.shared.generated.resources.Res
import recipeappkmp.shared.generated.resources._10_strawberries
import kotlin.time.Duration

val koreanList = listOf(
    Recipe(
        title = "Oi Muchim | Spicy Cucumber Salad",
        description = "Cucumbers tossed in vinegar and chili spices.",
        ingredients = listOf(
            "1 Cucumber",
            "1 Tsp Salt",
            "1 Tbsp Gochugaru",
            "1 Tbsp Scallion, chopped",
            "1 Tsp Garlic, minced",
            "1 Tsp Vinegar",
            "1/2 Tsp Sugar",
            "1 tsp Sesame Seeds",
            "1 Tsp Sesame Oil",
        ),
        instructions = listOf(
            "Thinly slice the Cucumber. Sprinkle with Salt [1 Tsp] and rest for 20 minutes.",
            "Drain liquid from Cucumbers, then toss in remaining ingredients.",
        ),
        tags = mapOf(
            "Korean" to TagType.CUISINE,
            "Appetizer" to TagType.COURSE,
            "Spicy" to TagType.FLAVOUR,
        ),
        image = Res.drawable._10_strawberries,
        cookTime = Duration.ZERO,
        prepTime = Duration.parse("30m")
    ),

    Recipe(
        title = "Korean Stir Fry Sauce",
        description = "Sweet and Spicy Korean Stir Fry Sauce.",
        ingredients = listOf(
            "1.5 Tbsp Gochujang",
            "2 Tsp Gochugaru",
            "1 Tbsp Garlic, minced",
            "1 Tsp Ginger, grated",
            "2 Tsp Honey",
            "1 Tbsp Soy",
            "1 Tbsp Mirin",
            "1.5 Tsp Brown Sugar",
            "Juice of 1 Lime",
        ),
        instructions = listOf(
            "Combine ingredients",
        ),
        tags = mapOf(
            "Korean" to TagType.CUISINE,
            "Sauce" to TagType.COURSE,
            "Spicy" to TagType.FLAVOUR,
            "Sweet" to TagType.FLAVOUR,
        ),
        image = Res.drawable._10_strawberries,
        cookTime = Duration.ZERO,
        prepTime = Duration.parse("10m")
    ),

    Recipe(
        title = "Bulgolgi",
        description = "Delicious Savory and Spicy (like all Korean food) Korean barbecue",
        ingredients = listOf(
            "2 Scallion",
            "1 Large Onion",
            "1 lb Protein of choice",
            "3 Tbsp Gochujang",
            "1 tsp Gochugaru",
            "2 Tbsp Soy",
            "2 Tbsp Mirin",
            "1.5 Tbsp Sugar",
            "1 Tbsp Sesame Oil",
            "1 Tbsp Garlic, minced",
            "1 Tbsp Ginger, grated",
            "1/4 Tsp Black Pepper"
        ),
        instructions = listOf(
            "Mix all ingredients except Scallions together. Marinate 1h, up to overnight",
            "Stir Fry until onions are done, protein is finished cooking, etc...",
            "Garnish with Scallions and serve"
        ),
        tags = mapOf(
            "Korean" to TagType.CUISINE,
            "Entree" to TagType.COURSE,
            "Spicy" to TagType.FLAVOUR,
            "Savory" to TagType.FLAVOUR,
            "Stir Fried" to TagType.TECHNIQUE,
        ),
        image = Res.drawable._10_strawberries,
        cookTime = Duration.parse("30m"),
        prepTime = Duration.parse("8h")
    ),

    Recipe(
        title = "Buldak | Fire Chicken",
        description = "Spicy Korean Barbecued Chicken",
        ingredients = listOf(

            "HEADER-Barbecue",
            "1 lb Protein of Choice (Originally Chicken)",
            "2 Tbsp Soy",
            "1 Tbsp Sugar",
            "1 Tbsp Honey",
            "2 Tbsp Rice Wine",
            "Black Pepper",
            "Sesame Seeds",
            "1 Scallion",

            "HEADER-Fire Sauce",
            "3 Tbsp Gochugaru",
            "2 Alapenos",
            "1/2 Cup Korean Pear",
            "1/4 White Onion",
            "3 Tbsp Garlic, minced",
            "2 Tbsp Soy Sauce",
            "1 Tsp Spicy Yellow Mustard",
            "1 Tbsp Sesame Oil",
            "1 Tbsp Honey",
        ),
        instructions = listOf(
            "Cut the Protein into Bite-sized pieces",
            "In a bowl, mix Soy [2 Tbsp], Sugar [1 Tbsp], Honey [1 Tbsp], Rice Wine [2 Tbsp], and Black Pepper. Toss the Protein in this mixture; marinate for 30m.",
            "Puree all the Fire Sauce ingredients together in a blender. Set Aside.",
            "Heat a wok over medium heat, cooking Protein to just underdone in batches as needed.",
            "Pull the Protein, leaving as much of everything else in the wok as you can. Toss in the Fire Sauce and return all to the wok.",
            "Cook another 3-4 minutes until all are warmed through."
        ),
        tags = mapOf(
            "Korean" to TagType.CUISINE,
            "Entree" to TagType.COURSE,
            "Savory" to TagType.FLAVOUR,
            "Spicy" to TagType.FLAVOUR,
            "Barbecue" to TagType.TECHNIQUE,
        ),
        prepTime = Duration.parse("40m"),
        cookTime = Duration.parse("15m"),
        image = Res.drawable._10_strawberries
    )
)
